@@ -3,11 +3,10 @@
 
 import time
 import board
-import busio
 import digitalio
 import adafruit_max31855
 
-spi = busio.SPI(board.SCK, MOSI=board.MOSI, MISO=board.MISO)
+spi = board.SPI()
 cs = digitalio.DigitalInOut(board.D5)
 
 max31855 = adafruit_max31855.MAX31855(spi, cs)
